/*
 * This file is part of the KDE Milou Project
 * SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
 *
 * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 *
 */

// This is the width of the side component which displays the categories
// of the results, such as "Applications", "Audio", "Video", etc
var CategoryWidth = units.gridUnit * 10;
var CategoryRightMargin = units.largeSpacing;

// The Maximum and Minimum width of the Plasmoid
var PlasmoidWidth = units.gridUnit * 35;

var IconSize = units.iconSizes.small

// This title size is only used in the Audio plugin
// var TitleSize = isHighDPI ? TitleSizeHighDPI : TitleSizeNormal
